@@ -7,13 +7,18 @@ OC.L10N.register(
     "Disabled" : "Onemogućeno",
     "Users" : "Korisnici",
     "Name" : "Ime",
+    "Language" : "Jezik",
+    "Country" : "Država",
+    "Status" : "Status",
+    "Pending" : "Na čekanju",
+    "Error" : "Greška",
+    "Blocked" : "Blokiran",
     "Saved" : "Spremljeno",
     "Favorite" : "Favorit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "Grupe",
-    "Error" : "Greška",
     "Password protect" : "Zaštitita lozinkom",
     "Close" : "Zatvori",
     "Today" : "Danas",
