@@ -16,6 +16,7 @@ OC.L10N.register(
     "Join call" : "Unirse a la llamada",
     "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
+    "Open settings" : "Abrir configuraciones",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "Limit to groups" : "Limitar a grupos",
@@ -28,6 +29,13 @@ OC.L10N.register(
     "Users" : "Ususarios",
     "Name" : "Nombre",
     "General settings" : "Configuraciones generales",
+    "Language" : "Idioma",
+    "Country" : "País",
+    "Status" : "Estatus",
+    "Created at" : "Creado en",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Blocked" : "Bloqueado",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Guardado",
     "Shared secret" : "Secreto compartido",
@@ -43,6 +51,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Dismiss" : "Descartar",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
@@ -61,7 +70,6 @@ OC.L10N.register(
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Error" : "Error",
     "Password protect" : "Proteger con contraseña",
     "Back" : "Atrás",
     "Close" : "Cerrar",
@@ -78,7 +86,6 @@ OC.L10N.register(
     "Chat" : "Chat",
     "Settings" : "Configuraciones ",
     "Edit" : "Editar",
-    "Dismiss" : "Descartar",
     "Share link" : "Compartir liga",
     "Password protection" : "Protección con contraseña",
     "Enter a password" : "Ingresa una contraseña",
