@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados"],
     "Guest" : "Invitado",
+    "Open settings" : "Abrir opciones",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "Limit to groups" : "Limitar a grupos",
@@ -16,6 +17,13 @@ OC.L10N.register(
     "Name" : "Nombre",
     "General settings" : "Configuraciones generales",
     "Off" : "Apagado",
+    "Language" : "Idioma",
+    "Country" : "País",
+    "Status" : "Estatus",
+    "Created at" : "Creado en",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Blocked" : "Bloqueado",
     "Saved" : "Guardado",
     "TURN server protocols" : "Protocolos del servidor TURN",
     "UDP and TCP" : "UDP y TCP",
@@ -25,6 +33,7 @@ OC.L10N.register(
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "Show your screen" : "Mostrar su pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Dismiss" : "Despedir",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -41,7 +50,6 @@ OC.L10N.register(
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Error" : "Error",
     "Password protect" : "Proteger con contraseña",
     "Back" : "Atrás",
     "Close" : "Cerrar",
@@ -57,7 +65,6 @@ OC.L10N.register(
     "Chat" : "Chat",
     "Settings" : "Ajustes",
     "Edit" : "Editar",
-    "Dismiss" : "Despedir",
     "Rename conversation" : "Renombrar conversación",
     "Share link" : "Compartir link",
     "Password protection" : "Protección con contraseña",
