@@ -16,6 +16,8 @@ OC.L10N.register(
     "Join call" : "Unirse a la llamada",
     "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
+    "Open settings" : "Abrir configuraciones",
+    "Conversations" : "Conversaciones",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "This conversation has ended" : "Esta conversación ha terminado",
@@ -29,6 +31,14 @@ OC.L10N.register(
     "Users" : "Usuarios",
     "Name" : "Nombre",
     "General settings" : "Configuraciones generales",
+    "Language" : "Idioma",
+    "Country" : "País",
+    "Status" : "Estatus",
+    "Created at" : "Creado en",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Blocked" : "Bloqueado",
+    "Expired" : "Expirado",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Guardado",
     "Shared secret" : "Secreto compartido",
@@ -45,6 +55,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Dismiss" : "Descartar",
     "No audio" : "Sin audio",
     "Mute audio (m)" : "Silenciar audio (m)",
     "Unmute audio (m)" : "Habilitar audio (m)",
@@ -60,19 +71,16 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
-    "Your screen" : "Tu pantalla",
+    "You" : "Tú",
     "Show screen" : "Mostrar pantalla",
     "Favorite" : "Hacer favorito",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Borrar conversación",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
-    "Conversations" : "Conversaciones",
-    "Contacts" : "Contactos",
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Error" : "Error",
     "Password protect" : "Proteger con contraseña",
     "Back" : "Atrás",
     "Close" : "Cerrar",
@@ -86,11 +94,11 @@ OC.L10N.register(
     "Promote to moderator" : "Promover a moderador",
     "Remove participant" : "Eliminar participante",
     "No results" : "No hay resultados",
+    "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
     "Settings" : "Configuraciones ",
     "Edit" : "Editar",
-    "Dismiss" : "Descartar",
     "Rename conversation" : "Renombrar conversación",
     "Share link" : "Compartir liga",
     "Password protection" : "Protección con contraseña",
@@ -129,7 +137,6 @@ OC.L10N.register(
     "Link copied!" : "¡Liga copiada!",
     "Conversation with {name}" : "Conversación con {name}",
     "Error occurred while setting password" : "Se presentó un error al establecer al contraseña",
-    "You" : "Tú",
     "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
     "New message …" : "Mensaje nuevo ...",
     "Send" : "Enviar",
@@ -147,7 +154,9 @@ OC.L10N.register(
     "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
     "Add participant …" : "Agregar participante ...",
     "Favorited" : "Marcado como favorito",
+    "Your screen" : "Tu pantalla",
     "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado"
+    "Guest's screen" : "Pantalla del invitado",
+    "Contacts" : "Contactos"
 },
 "nplurals=2; plural=(n != 1);");
