@@ -16,6 +16,8 @@ OC.L10N.register(
     "Join call" : "Unirse a la llamada",
     "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
+    "Open settings" : "Abrir configuraciones",
+    "Conversations" : "Conversaciones",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "This conversation has ended" : "Esta conversación ha terminado",
@@ -29,6 +31,14 @@ OC.L10N.register(
     "Users" : "Usuarios",
     "Name" : "Nombre",
     "General settings" : "Configuraciones generales",
+    "Language" : "Idioma",
+    "Country" : "País",
+    "Status" : "Estatus",
+    "Created at" : "Creado en",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Blocked" : "Bloqueado",
+    "Expired" : "Expirado",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Guardado",
     "Shared secret" : "Secreto compartido",
@@ -45,6 +55,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Dismiss" : "Descartar",
     "No audio" : "Sin audio",
     "Mute audio (m)" : "Silenciar audio (m)",
     "Unmute audio (m)" : "Habilitar audio (m)",
@@ -67,11 +78,9 @@ OC.L10N.register(
     "Delete conversation" : "Borrar conversación",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
-    "Conversations" : "Conversaciones",
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Error" : "Error",
     "Password protect" : "Proteger con contraseña",
     "Back" : "Atrás",
     "Close" : "Cerrar",
@@ -90,7 +99,6 @@ OC.L10N.register(
     "Chat" : "Chat",
     "Settings" : "Configuraciones ",
     "Edit" : "Editar",
-    "Dismiss" : "Descartar",
     "Rename conversation" : "Renombrar conversación",
     "Share link" : "Compartir liga",
     "Password protection" : "Protección con contraseña",
