@@ -12,15 +12,23 @@ OC.L10N.register(
     "Disabled" : "Keelatud",
     "Users" : "Kasutajad",
     "Name" : "Nimi",
+    "Language" : "Keel",
+    "Country" : "Riik",
+    "Status" : "Staatus",
+    "Created at" : "Loodud",
+    "Pending" : "Ootel",
+    "Error" : "Viga",
+    "Blocked" : "Blokeeritud",
+    "Expired" : "Aegunud",
     "Saved" : "Salvestatud",
     "Copy link" : "Kopeeri link",
+    "Dismiss" : "Jäta vahele",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
     "Favorite" : "Lemmik",
     "Remove from favorites" : "Eemalda lemmikutest",
     "Add to favorites" : "Lisa lemmikutesse",
     "Loading" : "Laadimine",
     "Groups" : "Grupid",
-    "Error" : "Viga",
     "Password protect" : "Parooliga kaitsmine",
     "Back" : "Tagasi",
     "Close" : "Sulge",
@@ -28,11 +36,11 @@ OC.L10N.register(
     "Today" : "Täna",
     "Yesterday" : "Eile",
     "guest" : "külaline",
+    "Searching …" : "Otsin ...",
     "No results" : "Vasteid ei leitud",
     "Add users or groups" : "Add users or groups",
     "Settings" : "Seaded",
     "Edit" : "Redigeeri",
-    "Dismiss" : "Jäta vahele",
     "Share link" : "Jaga link",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
