@@ -83,8 +83,164 @@ OC.L10N.register(
     "File is not shared, or shared but not with the user" : "پرونده به اشتراک گذاشته نمی شود ، یا به اشتراک گذاشته اما با کاربر به اشتراک گذاشته نمی شود",
     "Write to conversation" : "برای مکالمه بنویسید",
     "Writes event information into a conversation of your choice" : "اطلاعات رویداد را در گفتگوی مورد نظر شما می نویسد",
+    "%s invited you to a conversation." : "%s شما را به یک گفتگو دعوت کرد",
+    "You were invited to a conversation." : "شما به یک گفتگو دعوت شده اید",
     "Private conversation" : "مکالمه خصوصی",
+    "{user} invited you to a private conversation" : "{user} شما را به یک گفتگوی خصوصی دعوت کرد",
+    "{user} invited you to a group conversation: {call}" : "{user} شما را به یک گفتگو گروهی دعوت کرد: {call}",
+    "Open settings" : "تنظیمات را باز کنید",
+    "United Arab Emirates" : "امارات متحده عربی",
+    "Afghanistan" : "افغانستان",
+    "Albania" : "آلبانی",
+    "Armenia" : "ارمنستان",
+    "Angola" : "آنگولا",
+    "Argentina" : "آرژانتین",
+    "Austria" : "استرالیا",
+    "Australia" : "استرالیا",
+    "Azerbaijan" : "آذربایجان",
+    "Bangladesh" : "بنگلادش",
+    "Belgium" : "بلژیک",
+    "Burkina Faso" : "بورکینافاسو",
+    "Bulgaria" : "بلغارستان",
+    "Burundi" : "بوروندی",
+    "Benin" : "بنین",
+    "Brazil" : "برزیل",
+    "Bahamas" : "باهاما",
+    "Bhutan" : "بوتان",
+    "Botswana" : "بوتسوانا",
+    "Belarus" : "بلاروس",
+    "Belize" : "بلیز",
+    "Canada" : "کانادا",
+    "Central African Republic" : "جمهوری آفریقای مرکزی",
+    "Congo" : "کنگو",
+    "Switzerland" : "سوئیس",
+    "Chile" : "شیلی",
+    "Cameroon" : "کامرون",
+    "China" : "چین",
+    "Colombia" : "کلومبیا",
+    "Costa Rica" : "کاستاریکا",
+    "Cuba" : "کوبا",
+    "Cyprus" : "قبرس",
+    "Germany" : "آلمان",
+    "Djibouti" : "جیبوتی",
+    "Denmark" : "دانمارک",
+    "Dominican Republic" : "جمهوری دومینیکن",
+    "Algeria" : "الجزایر",
+    "Ecuador" : "اکوادور",
+    "Estonia" : "استونی",
+    "Egypt" : "مصر",
+    "Eritrea" : "اریتره",
+    "Spain" : "اسپانیا",
+    "Ethiopia" : "اتیوپی",
+    "Finland" : "فنلاند",
+    "Fiji" : "فیجی",
+    "France" : "فرانسه",
+    "Gabon" : "گابن",
+    "Georgia" : "جورجیا",
+    "Ghana" : "غنا",
+    "Greenland" : "گرینلند",
+    "Gambia" : "گامبیا",
+    "Guinea" : "گینه",
+    "Equatorial Guinea" : "گینه استوایی",
+    "Greece" : "یونان",
+    "Guatemala" : "گواتمالا",
+    "Guinea-Bissau" : "گینه بیسائو",
+    "Guyana" : "گویان",
+    "Honduras" : "هندوراس",
+    "Croatia" : "کرواسی",
+    "Haiti" : "هائیتی",
+    "Hungary" : "مجارستان",
+    "Indonesia" : "اندونزی",
+    "Ireland" : "ایرلند",
+    "Israel" : "اسرائیل",
+    "India" : "هند",
+    "Iraq" : "عراق",
+    "Iceland" : "ایسلند",
+    "Italy" : "ایتالیا",
+    "Jamaica" : "جامایکا",
+    "Jordan" : "جردن",
+    "Japan" : "ژاپن",
+    "Kenya" : "کنیا",
+    "Kyrgyzstan" : "قرقیزستان",
+    "Cambodia" : "کمبوج",
+    "Kuwait" : "کویت",
+    "Kazakhstan" : "قزاقستان",
+    "Lebanon" : "لبنان",
+    "Sri Lanka" : "سریلانکا",
+    "Liberia" : "لیبریا",
+    "Lesotho" : "لسوتو",
+    "Lithuania" : "لیتوانی",
+    "Luxembourg" : "لوکزامبورگ",
+    "Latvia" : "لتونی",
+    "Libya" : "لیبی",
+    "Morocco" : "مراکش",
+    "Montenegro" : "مونتنگرو",
+    "Madagascar" : "ماداگاسکار",
+    "Mali" : "مالی",
+    "Myanmar" : "میانمار",
+    "Mongolia" : "مغولستان",
+    "Mauritania" : "موریتانی",
+    "Malawi" : "مالاوی",
+    "Mexico" : "مکزیک",
+    "Malaysia" : "مالزی",
+    "Mozambique" : "موزامبیک",
+    "Namibia" : "ناميبيا",
+    "New Caledonia" : "کالدونیای جدید",
+    "Niger" : "نیجر",
+    "Nigeria" : "نیجرا",
+    "Nicaragua" : "نیجریه",
+    "Netherlands" : "هلند",
+    "Norway" : "نروژ",
+    "Nepal" : "نپال",
+    "New Zealand" : "نیوزلند",
+    "Oman" : "عمان",
+    "Panama" : "پاناما",
+    "Peru" : "پرو",
+    "Papua New Guinea" : "پاپوا گینه نو",
+    "Philippines" : "فلیپین",
+    "Pakistan" : "پاکستان",
+    "Poland" : "لهستان",
+    "Puerto Rico" : "پورتوریکو",
+    "Portugal" : "پرتغال",
+    "Paraguay" : "پاروگیه",
+    "Qatar" : "قطر",
+    "Romania" : "رومانی",
+    "Serbia" : "صربستان",
+    "Rwanda" : "رواندا",
+    "Saudi Arabia" : "عربستان",
+    "Solomon Islands" : "جزایر سلیمان",
+    "Sudan" : "سودان",
+    "Sweden" : "سوئد",
+    "Singapore" : "سنگاپور",
+    "Slovenia" : "اسلونی",
+    "Slovakia" : "اسلواکی",
+    "Sierra Leone" : "سیرا لئون",
+    "Senegal" : "سنگال",
+    "Somalia" : "سومالی",
+    "Suriname" : "سوریه",
+    "South Sudan" : "سومالی شمالی",
+    "El Salvador" : "سلوادور",
+    "Chad" : "چد",
+    "Togo" : "توگو",
+    "Thailand" : "تایلند",
+    "Tajikistan" : "تاجیکستان",
+    "Timor-Leste" : "تیمور-لست",
+    "Turkmenistan" : "ترکمنستان",
+    "Tunisia" : "تونس",
+    "Tonga" : "تونگا",
+    "Turkey" : "jv;di",
+    "Trinidad and Tobago" : "ترینیداد و توباگو",
+    "Ukraine" : "اوکراین",
+    "Uganda" : "اوگاندا",
+    "Uruguay" : "اوروگویه",
+    "Uzbekistan" : "اوزبکستان",
+    "Vanuatu" : "وانتویو",
+    "Yemen" : "یمن",
+    "South Africa" : "آفریقا شمالی",
+    "Zambia" : "زامبی",
+    "Zimbabwe" : "زیمباوه",
     "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر است ، قالب تاریخ باید YYYY-MM-DD باشد",
+    "Join conversation" : "عضویت در گفتگو",
     "Limit to groups" : "محدود کردن به گروه ها",
     "Everyone" : "همه",
     "Save changes" : "ذخیره تغییرات",
@@ -96,8 +252,20 @@ OC.L10N.register(
     "Name" : "نام",
     "General settings" : "تنظیمات عمومی",
     "Off" : "خاموش",
+    "Language" : "زبان",
+    "Country" : "کشور",
+    "Status" : "وضعیت",
+    "Created at" : "ایجاد شده در",
+    "Pending" : "در انتظار",
+    "Error" : "خطا",
+    "Blocked" : "مسدود کردن",
+    "Active" : "فعال کردن",
+    "Expired" : "منقضی شده",
     "Saved" : "ذخیره شد",
     "Copy link" : "کپی کردن لینک",
+    "You can invite others in the participant tab of the sidebar" : "شما می‌توانید دیگران را از زبانه اعضا در نوارکناری دعوت کنید",
+    "Share this link to invite others!" : "این پیوند را به اشتراک بگذارید تا دیگران را دعوت کنید!",
+    "Dismiss" : "پنهان کن",
     "You" : "شما",
     "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
     "Favorite" : "برگزیده",
@@ -108,11 +276,13 @@ OC.L10N.register(
     "Loading" : "در حال بار گزاری",
     "Groups" : "گروه ها",
     "Circles" : "حلقه ها",
-    "Error" : "خطا",
+    "Create a new group conversation" : "ساخت گفتگوی گروهی جدید",
     "Password protect" : "نگهداری کردن رمز عبور",
+    "Add participants" : "افزودن عضو",
     "Back" : "بازگشت",
     "Close" : "بستن",
     "Conversation name" : "نام مکالمه",
+    "Allow guests to join via link " : "مجاز بودن عضویت مهمان‌ها با پیوند",
     "Reply" : "پاسخ",
     "Today" : "Today",
     "Yesterday" : "دیروز",
@@ -124,16 +294,20 @@ OC.L10N.register(
     "Searching …" : "جستجوکردن …",
     "No results" : "نتیجه ای یافت نشد",
     "Add users or groups" : "کاربران یا گروه ها را اضافه کنید",
+    "Add participants to the conversation" : "افزودن عضو به گفتگو",
     "Participants" : "شركت كنندگان",
     "Projects" : "پروژه ها",
     "Settings" : "تنظیمات",
     "Edit" : "ویرایش",
-    "Dismiss" : "پنهان کن",
     "Rename conversation" : "تغییر نام مکالمه",
     "Share link" : "Share link",
     "Password protection" : "Password protection",
     "Enter a password" : "یک گذرواژه وارد کنید",
+    "Fullscreen (f)" : "تمام صفحه (f)",
     "Grid view" : "نمایش گرید",
+    "Join a conversation or start a new one!" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید!",
+    "Join a conversation or start a new one" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید",
+    "Say hi to your friends and colleagues!" : "به رفقا و همدرس‌هایتان سلام کنید!",
     "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
     "Password" : "گذرواژه",
     "Android app" : "اپ اندروید",
@@ -154,6 +328,7 @@ OC.L10N.register(
     "Send" : "ارسال",
     "Share" : "هم‌رسانی",
     "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
+    "Add participant …" : "افزودن اعضا ...",
     "Favorited" : "برگزیده شده",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- مکالمات اکنون می توانند یک لابی داشته باشند. این به مدیران اجازه می دهد تا برای تهیه جلسه به چت بپیوندند و از قبل تماس بگیرند ، در حالی که کاربران و میهمانان باید منتظر بمانند.",
     "Contacts" : "مخاطبین"
