@@ -8,17 +8,21 @@ OC.L10N.register(
     "User" : "User",
     "Users" : "Usatores",
     "Name" : "Nomine",
+    "Language" : "Lingua",
+    "Country" : "Pais",
+    "Pending" : "Pendente",
+    "Error" : "Error",
     "Saved" : "Salveguardate",
     "UDP only" : "solo UDP",
     "TCP only" : "solo TCP",
     "Copy link" : "Copiar ligamine",
+    "Dismiss" : "Dimitter",
     "You" : "Tu",
     "Favorite" : "Favorite",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "Gruppos",
-    "Error" : "Error",
     "Password protect" : "Proteger per contrasigno",
     "Back" : "Retro",
     "Close" : "Clauder",
@@ -29,7 +33,6 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Settings" : "Configurationes",
     "Edit" : "Modificar",
-    "Dismiss" : "Dimitter",
     "Share link" : "Compartir ligamine",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
