@@ -16,6 +16,7 @@ OC.L10N.register(
     "Join call" : "შეუერთდით ზარს",
     "{user} wants to talk with you" : "{user} მომხმარებელს სურს თქვენთან საუბარი",
     "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
+    "Open settings" : "პარამეტრების გახსნა",
     "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
     "Leave call" : "ზარის დატოვება",
     "Limit to groups" : "ლიმიტი ჯგუფებზე",
@@ -28,6 +29,14 @@ OC.L10N.register(
     "Users" : "მომხმარებლები",
     "Name" : "სახელი",
     "General settings" : "მთავარი პარამეტრები",
+    "Language" : "ენა",
+    "Country" : "ქვეყანა",
+    "Status" : "სტატუსი",
+    "Created at" : "შეიქმნა",
+    "Pending" : "მოლოდინში",
+    "Error" : "შეცდომა",
+    "Blocked" : "დაბლოკილია",
+    "Expired" : "გაუქმდა",
     "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
     "Saved" : "დამახსოვრდა",
     "Shared secret" : "გაზიარებული საიდუმლო",
@@ -43,6 +52,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
     "Show your screen" : "თქვენი ეკრანის ჩვენება",
     "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
+    "Dismiss" : "დათხოვნა",
     "Mute audio" : "ხმის ჩახშობა",
     "Disable video" : "ვიდეოს გათიშვა",
     "Enable video" : "ვიდეოს ამოქმედება",
@@ -61,7 +71,6 @@ OC.L10N.register(
     "Loading" : "იტვირთება",
     "Groups" : "ჯგუფები",
     "Circles" : "წრეები",
-    "Error" : "შეცდომა",
     "Password protect" : "პაროლით დაცვა",
     "Back" : "უკან",
     "Close" : "დახურვა",
@@ -80,7 +89,6 @@ OC.L10N.register(
     "Chat" : "ჩეთი",
     "Settings" : "პარამეტრები",
     "Edit" : "შეცვლა",
-    "Dismiss" : "დათხოვნა",
     "Share link" : "ბმულის გაზიარება",
     "Password protection" : "პაროლით თავდაცვა",
     "Enter a password" : "შეიყვანეთ პაროლი",
