@@ -10,14 +10,21 @@ OC.L10N.register(
     "Disabled" : "идэвхигүй",
     "Users" : "хэрэглэгч",
     "Name" : "Нэр",
+    "Language" : "Хэл",
+    "Country" : "Улс",
+    "Status" : "төлөв",
+    "Created at" : "үүсгэгдсэн",
+    "Pending" : "Хүлээгдэж байгаа",
+    "Error" : "Алдаа",
+    "Blocked" : "Хаагдсан",
     "Saved" : "Хадгалах",
+    "Dismiss" : "Арилгах",
     "Favorite" : "Дуртай",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "бүлэгүүд",
     "Circles" : "Тойрог",
-    "Error" : "Алдаа",
     "Password protect" : "Нууц үгээр хамгаалах",
     "Back" : "буцах",
     "Close" : "Хаах",
@@ -28,7 +35,6 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Settings" : "Тохиргоо",
     "Edit" : "засварлах",
-    "Dismiss" : "Арилгах",
     "Share link" : "Холбоос хуваалцах",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
