@@ -6,13 +6,19 @@ OC.L10N.register(
     "User" : "Bruker",
     "Users" : "Brukarare",
     "Name" : "Namn",
+    "Language" : "Språk",
+    "Country" : "Land",
+    "Status" : "Status",
+    "Created at" : "Skapt den",
+    "Pending" : "Under vegs",
+    "Error" : "Feil",
     "Saved" : "Lagra",
+    "Dismiss" : "Forkast",
     "Favorite" : "Favoritt",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "Grupper",
-    "Error" : "Feil",
     "Password protect" : "Vern med passord",
     "Back" : "Tilbake",
     "Close" : "Lukk",
@@ -22,7 +28,6 @@ OC.L10N.register(
     "Chat" : "Lynmelding",
     "Settings" : "Instillingar",
     "Edit" : "Endra",
-    "Dismiss" : "Forkast",
     "Share link" : "Del lenkje",
     "Password protection" : "Password protection",
     "Enter a password" : "Skriv inn eit passord",
