@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "a conversation" : "розмова",
     "(Duration %s)" : "(Тривалість %s)",
+    "_%n guest_::_%n guests_" : ["%n гість","%n гостя","%n гостей","%n гостей"],
     "Talk" : "Розмови",
     "Guest" : "Гість",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "Дозволити гостям приєднуватися через посилання",
@@ -16,6 +17,7 @@ OC.L10N.register(
     "{actor} left the call" : "{actor} залишив розмову",
     "You left the call" : "Ви залишили розмову",
     "You allowed guests" : "Ви дозволили доступ гостям",
+    "An administrator allowed guests" : "Адміністратор дозволив гостей",
     "You set a password" : "Ви встановили пароль",
     "You joined the conversation" : "Ви приєдналися до розмови",
     "Talk to %s" : "Спілкуватися з %s",
@@ -28,74 +30,115 @@ OC.L10N.register(
     "You missed a call from {user}" : "Ви пропустили виклик від {user}",
     "Conversation not found" : "Розмову не знайдено",
     "Leave call" : "Вийти",
+    "Stay in call" : "Залишатися",
+    "Share this file" : "Поділитися файлом",
+    "Join conversation" : "Приєднатися",
     "Limit to groups" : "Обмежити групами",
+    "Guests can still join public conversations." : "Гості все ще можуть приєднуватися до публічних розмов.",
     "Everyone" : "Всі",
+    "Users and moderators" : "Учасники та модератори",
+    "Moderators only" : "Тільки модератори",
     "Save changes" : "Зберегти зміни",
     "Saving …" : "Збереження ..",
     "Saved!" : "Збережено!",
     "None" : "Відсутній",
     "User" : "Користувач",
     "Disabled" : "Вимкнено",
+    "Moderators" : "Модератори",
     "Users" : "Користувачі",
+    "Commands" : "Команди",
     "Beta" : "Бета",
     "Name" : "Ім'я",
+    "Command" : "Команда",
+    "Script" : "Скрипт",
+    "Enabled for" : "Увімкнено для",
     "General settings" : "Загальні налаштування",
+    "All messages" : "Всі повідомлення",
+    "@-mentions only" : "Тільки @-згадки",
     "Off" : "Вимкнути",
+    "Language" : "Мова",
+    "Country" : "Країна",
+    "Status" : "Статус",
+    "Created at" : "Створено",
+    "Pending" : "Очікування",
+    "Error" : "Помилка",
+    "Blocked" : "Заблоковано",
+    "Delete this server" : "Вилучити цей сервер",
     "Saved" : "Збережено",
     "Copy link" : "Скопіювати посилання",
     "Waiting for others to join the call …" : "Чекаємо, доки хтось приєднається до виклику...",
     "Share this link to invite others!" : "Поділіться цим посиланням з тими, кого бажаєте запросити!",
+    "Show your screen" : "Демонстрація екрану",
     "Stop screensharing" : "Припинити демонстрацію екрану",
+    "Dismiss" : "Припинити",
     "No audio" : "Вимкнути мікрофон",
     "Mute audio (m)" : "Вимкнути мікрофон (m)",
     "Unmute audio (m)" : "Увімкнути мікрофон (m)",
     "Mute audio" : "Вимкнути мікрофон (m)",
     "Unmute audio" : "Увімкнути мікрофон",
     "No camera" : "Вимкнути камеру",
+    "Disable video (v)" : "Вимкнути відео (v)",
+    "Enable video (v)" : "Увімкнути відео (v)",
+    "Disable video" : "Вимкнути відео",
+    "Enable video" : "Увімкнути відео",
     "Screensharing options" : "Параметри демонстрації екрану",
     "Enable screensharing" : "Увімкнути демонстрацію екрану",
     "Screen sharing requires the page to be loaded through HTTPS." : "Демонстрація екрану вимагає доступу до сторінки через безпечний протокол https.",
     "Screensharing requires the page to be loaded through HTTPS." : "Демонстрація екрану вимагає доступу до сторінки через безпечний протокол https.",
     "You" : "Ви",
+    "Show screen" : "Демонстрація екрану",
+    "Mute" : "Вимкнути звук",
     "You need to be logged in to upload files" : "Для завантаження файлів потрібно авторизуватися",
     "Drop your files to upload" : "Пересуньте файли сюди для завантаження",
+    "Call in progress" : "Триває виклик",
     "Favorite" : "Улюблений",
     "Chat notifications" : "Сповіщення чату",
+    "Leave conversation" : "Залишити спілкування",
+    "Delete conversation" : "Вилучити розмову",
     "Remove from favorites" : "Вилучено з улюбленого",
-    "Add to favorites" : "Додати до обраного",
+    "Add to favorites" : "Додати до улюбленого",
+    "Do you really want to delete \"{displayName}\"?" : "Дійсно вилучити \"{displayName}\"?",
     "Loading" : "Завантаження",
     "No search results" : "Відсутні результати",
     "Groups" : "Групи",
     "Default location for attachments" : "Типове розташування для вкладень",
     "Select default location for attachments" : "Виберіть типове розташування для вкладень",
     "Invalid path selected" : "Вибрано неправильний шлях",
-    "Error" : "Помилка",
+    "Create a new group conversation" : "Створити нову групову розмову",
     "Password protect" : "Захистити паролем",
     "Add participants" : "Додати учасників",
     "Back" : "Назад",
+    "Create conversation" : "Створити розмову",
     "Close" : "Закрити",
     "Search participants" : "Пошук учасників",
     "Conversation name" : "Назва розмови",
+    "Allow guests to join via link " : "Дозволити гостям приєднуватися через посилання",
+    "Search conversations or users" : "Пошук розмов та учасників",
     "You are currently waiting in the lobby" : "Чекаємо на схвалення доступу",
     "Reply" : "Відповісти",
     "Today" : "Сьогодні",
     "Yesterday" : "Вчора",
-    "Write message, @ to mention someone …" : "Написати повідомлення, @ кому згадати когось…",
+    "Write message, @ to mention someone …" : "Написати повідомлення, @ім'я для згадки про користувача…",
     "Share files to the conversation" : "Поділитися файлами під час розмови",
-    "Upload new files" : "Завантажити файли",
-    "Share from Files" : "Поділитися із застосунку Файли",
+    "Upload new files" : "Додати файл",
+    "Share from Files" : "Відкрити Файли",
     "File to share" : "Виберіть файл для надання доступу",
     "guest" : "гість",
+    "Add users" : "Додати користувачів",
+    "Add groups" : "Додати групи",
     "Searching …" : "Пошук...",
     "No results" : "Немає результатів",
-    "Add users or groups" : "Add users or groups",
+    "Search for more users" : "Шукати інших користувачів",
+    "Add users, groups or circles" : "Додати користувачів, групи або кола",
+    "Add users or groups" : "Додати користувачів або групи",
+    "Add users or circles" : "Додати користувачів або кола",
     "Add participants to the conversation" : "Додати учасників до розмови",
     "Participants" : "Учасники",
     "Chat" : "Чат",
     "Projects" : "Проєкти",
     "Settings" : "Налаштування",
     "Edit" : "Редагувати",
-    "Dismiss" : "Припинити",
+    "Start call" : "Почати виклик",
     "Toggle fullscreen" : "Перемкнути на весь екран",
     "Rename conversation" : "Перейменувати розмову",
     "Share link" : "Поширити посилання",
@@ -106,6 +149,7 @@ OC.L10N.register(
     "Fullscreen (f)" : "На весь екран (f)",
     "Grid view" : "Упорядкування у формі сітки",
     "Join a conversation or start a new one!" : "Приєднайтеся до розмови або почніть нову!",
+    "Select a conversation to add to the project" : "Виберіть розмову, яку потрібно додати до проєкту",
     "Join a conversation or start a new one" : "Приєднайтеся до розмови або почніть нову",
     "Say hi to your friends and colleagues!" : "Привітайтеся з вашими друзями та колегами!",
     "Error while sharing file" : "Помилка під час надання спільного доступу до файлу",
@@ -113,8 +157,8 @@ OC.L10N.register(
     "Please move your setup to HTTPS" : "Будь ласка, налаштуйте безпечний доступ до сервера через https.",
     "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
     "Password" : "Пароль",
-    "Android app" : "Android-додаток",
-    "iOS app" : "iOS додаток",
+    "Android app" : "Застосунок для Android",
+    "iOS app" : "Застосунок для iOS",
     "Enter name for a new conversation" : "Зазначте ім'я для нової розмови",
     "Copy" : "Копіювати",
     "Copied!" : "Скопійовано!",
@@ -134,9 +178,12 @@ OC.L10N.register(
     "Error while sharing" : "Помилка при поширенні",
     "No Camera" : "Вимкнути камеру",
     "Favorited" : "Улюблений",
+    "Guest's screen" : "Екран гостя",
+    "Start calls" : "Почати виклики",
+    "Who can start a call?" : "Хто може здійснювати виклики?",
     "Contacts" : "Контакти",
     "Select participants" : "Виберіть учасників",
-    "Search conversations or contacts" : "Пошук розмови та контактів",
+    "Search conversations or contacts" : "Пошук розмов та контактів",
     "Search for more contacts" : "Шукати більше контактів"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
