@@ -7,13 +7,15 @@ OC.L10N.register(
     "Disabled" : "停用",
     "Users" : "用戶",
     "Name" : "名稱",
+    "Language" : "語言",
+    "Country" : "國家",
+    "Error" : "錯誤",
     "Saved" : "已儲存",
     "Copy link" : "複製連結",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "群組",
-    "Error" : "錯誤",
     "Password protect" : "密碼保護",
     "Back" : "返回",
     "Close" : "關閉",
