@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 /**
  *
@@ -45,7 +46,6 @@ use OCP\IUser;
  * pending notifications are removed if the messages are deleted.
  */
 class ChatManager {
-
 	public const EVENT_BEFORE_SYSTEM_MESSAGE_SEND = self::class . '::preSendSystemMessage';
 	public const EVENT_AFTER_SYSTEM_MESSAGE_SEND = self::class . '::postSendSystemMessage';
 	public const EVENT_BEFORE_MESSAGE_SEND = self::class . '::preSendMessage';
@@ -145,11 +145,12 @@ class ChatManager {
 	 * @param string $actorType
 	 * @param string $actorId
 	 * @param string $message
-	 * @param IComment|null $replyTo
 	 * @param \DateTime $creationDateTime
+	 * @param IComment|null $replyTo
+	 * @param string $referenceId
 	 * @return IComment
 	 */
-	public function sendMessage(Room $chat, Participant $participant, string $actorType, string $actorId, string $message, \DateTime $creationDateTime, ?IComment $replyTo): IComment {
+	public function sendMessage(Room $chat, Participant $participant, string $actorType, string $actorId, string $message, \DateTime $creationDateTime, ?IComment $replyTo, string $referenceId): IComment {
 		$comment = $this->commentsManager->create($actorType, $actorId, 'chat', (string) $chat->getId());
 		$comment->setMessage($message, self::MAX_CHAT_LENGTH);
 		$comment->setCreationDateTime($creationDateTime);
@@ -161,6 +162,11 @@ class ChatManager {
 			$comment->setParentId($replyTo->getId());
 		}
 
+		$referenceId = trim(substr($referenceId, 0, 40));
+		if ($referenceId !== '') {
+			$comment->setReferenceId($referenceId);
+		}
+
 		$event = new ChatParticipantEvent($chat, $comment, $participant);
 		$this->dispatcher->dispatch(self::EVENT_BEFORE_MESSAGE_SEND, $event);
 
