@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 /**
  *
@@ -27,6 +28,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Share;
 
+use OC\Files\Cache\Cache;
 use OCA\Talk\Events\ParticipantEvent;
 use OCA\Talk\Events\RemoveUserEvent;
 use OCA\Talk\Events\RoomEvent;
@@ -66,6 +68,9 @@ class RoomShareProvider implements IShareProvider {
 	// Special share type for user modified room shares
 	public const SHARE_TYPE_USERROOM = 11;
 
+	public const TALK_FOLDER = '/Talk';
+	public const TALK_FOLDER_PLACEHOLDER = '/{TALK_PLACEHOLDER}';
+
 	/** @var IDBConnection */
 	private $dbConnection;
 	/** @var ISecureRandom */
@@ -100,7 +105,7 @@ class RoomShareProvider implements IShareProvider {
 	}
 
 	public static function register(IEventDispatcher $dispatcher): void {
-		$listener = static function(ParticipantEvent $event)  {
+		$listener = static function (ParticipantEvent $event) {
 			$room = $event->getRoom();
 
 			if ($event->getParticipant()->getParticipantType() === Participant::USER_SELF_JOINED) {
@@ -111,7 +116,7 @@ class RoomShareProvider implements IShareProvider {
 		};
 		$dispatcher->addListener(Room::EVENT_AFTER_ROOM_DISCONNECT, $listener);
 
-		$listener = static function(RemoveUserEvent $event) {
+		$listener = static function (RemoveUserEvent $event) {
 			$room = $event->getRoom();
 
 			/** @var self $roomShareProvider */
@@ -120,7 +125,7 @@ class RoomShareProvider implements IShareProvider {
 		};
 		$dispatcher->addListener(Room::EVENT_AFTER_USER_REMOVE, $listener);
 
-		$listener = static function(RoomEvent $event) {
+		$listener = static function (RoomEvent $event) {
 			$room = $event->getRoom();
 
 			/** @var self $roomShareProvider */
@@ -306,6 +311,14 @@ class RoomShareProvider implements IShareProvider {
 
 		$share->setProviderId($this->identifier());
 
+		if (isset($data['f_permissions'])) {
+			$entryData = $data;
+			$entryData['permissions'] = $entryData['f_permissions'];
+			$entryData['parent'] = $entryData['f_parent'];
+			$share->setNodeCacheEntry(Cache::cacheEntryFromData($entryData,
+				\OC::$server->getMimeTypeLoader()));
+		}
+
 		return $share;
 	}
 
@@ -411,7 +424,7 @@ class RoomShareProvider implements IShareProvider {
 					'permissions' => $qb->createNamedParameter(0),
 					'stime' => $qb->createNamedParameter($share->getShareTime()->getTimestamp()),
 				])->execute();
-		} else if ($data['permissions'] !== 0) {
+		} elseif ($data['permissions'] !== 0) {
 			// Already a userroom share. Update it.
 			$qb = $this->dbConnection->getQueryBuilder();
 			$qb->update('share')
@@ -529,23 +542,23 @@ class RoomShareProvider implements IShareProvider {
 		$qb->select('*')
 			->from('share', 's')
 			->andWhere($qb->expr()->orX(
-				$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
-				$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
+				$qb->expr()->eq('s.item_type', $qb->createNamedParameter('file')),
+				$qb->expr()->eq('s.item_type', $qb->createNamedParameter('folder'))
 			))
 			->andWhere(
-				$qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM))
+				$qb->expr()->eq('s.share_type', $qb->createNamedParameter(IShare::TYPE_ROOM))
 			);
 
 		/**
 		 * Reshares for this user are shares where they are the owner.
 		 */
 		if ($reshares === false) {
-			$qb->andWhere($qb->expr()->eq('uid_initiator', $qb->createNamedParameter($userId)));
+			$qb->andWhere($qb->expr()->eq('s.uid_initiator', $qb->createNamedParameter($userId)));
 		} else {
 			$qb->andWhere(
 				$qb->expr()->orX(
-					$qb->expr()->eq('uid_owner', $qb->createNamedParameter($userId)),
-					$qb->expr()->eq('uid_initiator', $qb->createNamedParameter($userId))
+					$qb->expr()->eq('s.uid_owner', $qb->createNamedParameter($userId)),
+					$qb->expr()->eq('s.uid_initiator', $qb->createNamedParameter($userId))
 				)
 			);
 		}
@@ -553,7 +566,7 @@ class RoomShareProvider implements IShareProvider {
 		$qb->innerJoin('s', 'filecache' ,'f', $qb->expr()->eq('s.file_source', 'f.fileid'));
 		$qb->andWhere($qb->expr()->eq('f.parent', $qb->createNamedParameter($node->getId())));
 
-		$qb->orderBy('id');
+		$qb->orderBy('s.id');
 
 		$cursor = $qb->execute();
 		$shares = [];
@@ -779,7 +792,7 @@ class RoomShareProvider implements IShareProvider {
 			)
 				->selectAlias('st.id', 'storage_string_id')
 				->from('share', 's')
-				->orderBy('id')
+				->orderBy('s.id')
 				->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
 				->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'));
 
@@ -789,19 +802,21 @@ class RoomShareProvider implements IShareProvider {
 
 			// Filter by node if provided
 			if ($node !== null) {
-				$qb->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($node->getId())));
+				$qb->andWhere($qb->expr()->eq('s.file_source', $qb->createNamedParameter($node->getId())));
 			}
 
-			$rooms = array_map(function(Room $room) { return $room->getToken(); }, $rooms);
+			$rooms = array_map(function (Room $room) {
+				return $room->getToken();
+			}, $rooms);
 
-			$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
-				->andWhere($qb->expr()->in('share_with', $qb->createNamedParameter(
+			$qb->andWhere($qb->expr()->eq('s.share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
+				->andWhere($qb->expr()->in('s.share_with', $qb->createNamedParameter(
 					$rooms,
 					IQueryBuilder::PARAM_STR_ARRAY
 				)))
 				->andWhere($qb->expr()->orX(
-					$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
-					$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
+					$qb->expr()->eq('s.item_type', $qb->createNamedParameter('file')),
+					$qb->expr()->eq('s.item_type', $qb->createNamedParameter('folder'))
 				));
 
 			$cursor = $qb->execute();
@@ -835,7 +850,7 @@ class RoomShareProvider implements IShareProvider {
 		$pathSections = explode('/', $data['path'], 2);
 		// FIXME: would not detect rare md5'd home storage case properly
 		if ($pathSections[0] !== 'files'
-			&& in_array(explode(':', $data['storage_string_id'], 2)[0], array('home', 'object'))) {
+			&& in_array(explode(':', $data['storage_string_id'], 2)[0], ['home', 'object'])) {
 			return false;
 		}
 		return true;
@@ -945,7 +960,7 @@ class RoomShareProvider implements IShareProvider {
 		$cursor = $qb->execute();
 
 		$users = [];
-		while($row = $cursor->fetch()) {
+		while ($row = $cursor->fetch()) {
 			$type = (int)$row['share_type'];
 			if ($type === IShare::TYPE_ROOM) {
 				$roomToken = $row['share_with'];
@@ -960,7 +975,7 @@ class RoomShareProvider implements IShareProvider {
 					$users[$uid] = $users[$uid] ?? [];
 					$users[$uid][$row['id']] = $row;
 				}
-			} else if ($type === self::SHARE_TYPE_USERROOM && $currentAccess === true) {
+			} elseif ($type === self::SHARE_TYPE_USERROOM && $currentAccess === true) {
 				$uid = $row['share_with'];
 				$users[$uid] = $users[$uid] ?? [];
 				$users[$uid][$row['id']] = $row;
@@ -1067,7 +1082,7 @@ class RoomShareProvider implements IShareProvider {
 
 		$cursor = $qb->execute();
 		$ids = [];
-		while($row = $cursor->fetch()) {
+		while ($row = $cursor->fetch()) {
 			$ids[] = (int)$row['id'];
 		}
 		$cursor->closeCursor();
@@ -1104,7 +1119,7 @@ class RoomShareProvider implements IShareProvider {
 
 			$cursor = $qb->execute();
 			$ids = [];
-			while($row = $cursor->fetch()) {
+			while ($row = $cursor->fetch()) {
 				$ids[] = (int)$row['id'];
 			}
 			$cursor->closeCursor();
@@ -1141,7 +1156,7 @@ class RoomShareProvider implements IShareProvider {
 			);
 
 		$cursor = $qb->execute();
-		while($data = $cursor->fetch()) {
+		while ($data = $cursor->fetch()) {
 			$share = $this->createShareObject($data);
 
 			yield $share;
